@@ -1,14 +1,15 @@
 #!/usr/bin/python
 
 from __future__ import unicode_literals, division, absolute_import
-import os
-import logging
-from flexget import logger
-from flexget.options import get_parser
-from flexget import plugin
-from flexget.manager import Manager
 
-__version__ = '1.2.173'
+import logging
+import os
+
+from flexget import logger, plugin
+from flexget.manager import Manager
+from flexget.options import get_parser
+
+__version__ = '1.2.174'
 
 log = logging.getLogger('main')
 
